#[non_exhaustive]pub enum AnyGlobalAccountDataEvent {
Show 14 variants
Direct(GlobalAccountDataEvent<DirectEventContent>),
DoNotDisturb(GlobalAccountDataEvent<DoNotDisturbEventContent>),
IdentityServer(GlobalAccountDataEvent<IdentityServerEventContent>),
InvitePermissionConfig(GlobalAccountDataEvent<InvitePermissionConfigEventContent>),
UnstableInvitePermissionConfig(GlobalAccountDataEvent<UnstableInvitePermissionConfigEventContent>),
IgnoredUserList(GlobalAccountDataEvent<IgnoredUserListEventContent>),
PushRules(GlobalAccountDataEvent<PushRulesEventContent>),
SecretStorageDefaultKey(GlobalAccountDataEvent<SecretStorageDefaultKeyEventContent>),
SecretStorageKey(GlobalAccountDataEvent<SecretStorageKeyEventContent>),
MediaPreviewConfig(GlobalAccountDataEvent<MediaPreviewConfigEventContent>),
UnstableMediaPreviewConfig(GlobalAccountDataEvent<UnstableMediaPreviewConfigEventContent>),
AccountImagePack(GlobalAccountDataEvent<AccountImagePackEventContent>),
ImagePackRooms(GlobalAccountDataEvent<ImagePackRoomsEventContent>),
RecentEmoji(GlobalAccountDataEvent<RecentEmojiEventContent>),
}events only.Expand description
Any global account data event.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Direct(GlobalAccountDataEvent<DirectEventContent>)
m.direct
DoNotDisturb(GlobalAccountDataEvent<DoNotDisturbEventContent>)
unstable-msc4359 only.m.do_not_disturb
This variant uses the unstable type dm.filament.do_not_disturb.
This variant can also be deserialized from the m.do_not_disturb type.
IdentityServer(GlobalAccountDataEvent<IdentityServerEventContent>)
m.identity_server
InvitePermissionConfig(GlobalAccountDataEvent<InvitePermissionConfigEventContent>)
m.invite_permission_config
UnstableInvitePermissionConfig(GlobalAccountDataEvent<UnstableInvitePermissionConfigEventContent>)
unstable-msc4380 only.org.matrix.msc4380.invite_permission_config
IgnoredUserList(GlobalAccountDataEvent<IgnoredUserListEventContent>)
m.ignored_user_list
PushRules(GlobalAccountDataEvent<PushRulesEventContent>)
m.push_rules
SecretStorageDefaultKey(GlobalAccountDataEvent<SecretStorageDefaultKeyEventContent>)
m.secret_storage.default_key
SecretStorageKey(GlobalAccountDataEvent<SecretStorageKeyEventContent>)
m.secret_storage.key.*
MediaPreviewConfig(GlobalAccountDataEvent<MediaPreviewConfigEventContent>)
unstable-msc4278 only.m.media_preview_config
UnstableMediaPreviewConfig(GlobalAccountDataEvent<UnstableMediaPreviewConfigEventContent>)
unstable-msc4278 only.io.element.msc4278.media_preview_config
AccountImagePack(GlobalAccountDataEvent<AccountImagePackEventContent>)
unstable-msc2545 only.m.image_pack
This variant uses the unstable type im.ponies.user_emotes.
This variant can also be deserialized from the m.image_pack type.
ImagePackRooms(GlobalAccountDataEvent<ImagePackRoomsEventContent>)
unstable-msc2545 only.m.image_pack.rooms
This variant uses the unstable type im.ponies.emote_rooms.
This variant can also be deserialized from the m.image_pack.rooms type.
RecentEmoji(GlobalAccountDataEvent<RecentEmojiEventContent>)
m.recent_emoji
Implementations
Sourceimpl AnyGlobalAccountDataEvent
impl AnyGlobalAccountDataEvent
Sourcepub fn event_type(&self) -> GlobalAccountDataEventType
pub fn event_type(&self) -> GlobalAccountDataEventType
Returns the type of this event.
Sourcepub fn content(&self) -> AnyGlobalAccountDataEventContent
pub fn content(&self) -> AnyGlobalAccountDataEventContent
Returns the content for this event.