#[non_exhaustive]pub enum AnyGlobalAccountDataEventContent {
Show 14 variants
Direct(DirectEventContent),
DoNotDisturb(DoNotDisturbEventContent),
IdentityServer(IdentityServerEventContent),
InvitePermissionConfig(InvitePermissionConfigEventContent),
UnstableInvitePermissionConfig(UnstableInvitePermissionConfigEventContent),
IgnoredUserList(IgnoredUserListEventContent),
PushRules(PushRulesEventContent),
SecretStorageDefaultKey(SecretStorageDefaultKeyEventContent),
SecretStorageKey(SecretStorageKeyEventContent),
MediaPreviewConfig(MediaPreviewConfigEventContent),
UnstableMediaPreviewConfig(UnstableMediaPreviewConfigEventContent),
AccountImagePack(AccountImagePackEventContent),
ImagePackRooms(ImagePackRoomsEventContent),
RecentEmoji(RecentEmojiEventContent),
}Available on crate feature
events only.Expand description
Any global account data event.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Direct(DirectEventContent)
m.direct
DoNotDisturb(DoNotDisturbEventContent)
Available on crate feature
unstable-msc4359 only.m.do_not_disturb
This variant uses the unstable type dm.filament.do_not_disturb.
This variant can also be deserialized from the m.do_not_disturb type.
IdentityServer(IdentityServerEventContent)
m.identity_server
InvitePermissionConfig(InvitePermissionConfigEventContent)
m.invite_permission_config
UnstableInvitePermissionConfig(UnstableInvitePermissionConfigEventContent)
Available on crate feature
unstable-msc4380 only.org.matrix.msc4380.invite_permission_config
IgnoredUserList(IgnoredUserListEventContent)
m.ignored_user_list
PushRules(PushRulesEventContent)
m.push_rules
SecretStorageDefaultKey(SecretStorageDefaultKeyEventContent)
m.secret_storage.default_key
SecretStorageKey(SecretStorageKeyEventContent)
m.secret_storage.key.*
MediaPreviewConfig(MediaPreviewConfigEventContent)
Available on crate feature
unstable-msc4278 only.m.media_preview_config
UnstableMediaPreviewConfig(UnstableMediaPreviewConfigEventContent)
Available on crate feature
unstable-msc4278 only.io.element.msc4278.media_preview_config
AccountImagePack(AccountImagePackEventContent)
Available on crate feature
unstable-msc2545 only.m.image_pack
This variant uses the unstable type im.ponies.user_emotes.
This variant can also be deserialized from the m.image_pack type.
ImagePackRooms(ImagePackRoomsEventContent)
Available on crate feature
unstable-msc2545 only.m.image_pack.rooms
This variant uses the unstable type im.ponies.emote_rooms.
This variant can also be deserialized from the m.image_pack.rooms type.
RecentEmoji(RecentEmojiEventContent)
m.recent_emoji