#[non_exhaustive]pub enum AnyStrippedStateEvent {
Show 29 variants
PolicyRuleRoom(StrippedStateEvent<PossiblyRedactedPolicyRuleRoomEventContent>),
PolicyRuleServer(StrippedStateEvent<PossiblyRedactedPolicyRuleServerEventContent>),
PolicyRuleUser(StrippedStateEvent<PossiblyRedactedPolicyRuleUserEventContent>),
RoomAvatar(StrippedStateEvent<RoomAvatarEventContent>),
RoomCanonicalAlias(StrippedStateEvent<RoomCanonicalAliasEventContent>),
RoomCreate(StrippedStateEvent<RoomCreateEventContent>),
RoomEncryption(StrippedStateEvent<PossiblyRedactedRoomEncryptionEventContent>),
RoomEncrypted(StrippedStateEvent<PossiblyRedactedStateRoomEncryptedEventContent>),
RoomGuestAccess(StrippedStateEvent<PossiblyRedactedRoomGuestAccessEventContent>),
RoomHistoryVisibility(StrippedStateEvent<RoomHistoryVisibilityEventContent>),
RoomImagePack(StrippedStateEvent<PossiblyRedactedRoomImagePackEventContent>),
RoomJoinRules(StrippedStateEvent<RoomJoinRulesEventContent>),
RoomLanguage(StrippedStateEvent<PossiblyRedactedRoomLanguageEventContent>),
RoomMember(StrippedStateEvent<PossiblyRedactedRoomMemberEventContent>),
RoomName(StrippedStateEvent<PossiblyRedactedRoomNameEventContent>),
RoomPinnedEvents(StrippedStateEvent<PossiblyRedactedRoomPinnedEventsEventContent>),
RoomPolicy(StrippedStateEvent<PossiblyRedactedRoomPolicyEventContent>),
RoomPowerLevels(StrippedStateEvent<RoomPowerLevelsEventContent>),
RoomRetention(StrippedStateEvent<RoomRetentionEventContent>),
RoomServerAcl(StrippedStateEvent<RoomServerAclEventContent>),
RoomThirdPartyInvite(StrippedStateEvent<RoomThirdPartyInviteEventContent>),
RoomTombstone(StrippedStateEvent<PossiblyRedactedRoomTombstoneEventContent>),
RoomTopic(StrippedStateEvent<PossiblyRedactedRoomTopicEventContent>),
RoomPresenceSharing(StrippedStateEvent<PossiblyRedactedRoomPresenceSharingEventContent>),
SpaceChild(StrippedStateEvent<PossiblyRedactedSpaceChildEventContent>),
SpaceParent(StrippedStateEvent<PossiblyRedactedSpaceParentEventContent>),
BeaconInfo(StrippedStateEvent<PossiblyRedactedBeaconInfoEventContent>),
CallMember(StrippedStateEvent<CallMemberEventContent>),
MemberHints(StrippedStateEvent<PossiblyRedactedMemberHintsEventContent>),
}events only.Expand description
Any state event.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
PolicyRuleRoom(StrippedStateEvent<PossiblyRedactedPolicyRuleRoomEventContent>)
m.policy.rule.room
PolicyRuleServer(StrippedStateEvent<PossiblyRedactedPolicyRuleServerEventContent>)
m.policy.rule.server
PolicyRuleUser(StrippedStateEvent<PossiblyRedactedPolicyRuleUserEventContent>)
m.policy.rule.user
RoomAvatar(StrippedStateEvent<RoomAvatarEventContent>)
m.room.avatar
RoomCanonicalAlias(StrippedStateEvent<RoomCanonicalAliasEventContent>)
m.room.canonical_alias
RoomCreate(StrippedStateEvent<RoomCreateEventContent>)
m.room.create
RoomEncryption(StrippedStateEvent<PossiblyRedactedRoomEncryptionEventContent>)
m.room.encryption
RoomEncrypted(StrippedStateEvent<PossiblyRedactedStateRoomEncryptedEventContent>)
unstable-msc4362 only.m.room.encrypted
RoomGuestAccess(StrippedStateEvent<PossiblyRedactedRoomGuestAccessEventContent>)
m.room.guest_access
RoomHistoryVisibility(StrippedStateEvent<RoomHistoryVisibilityEventContent>)
m.room.history_visibility
RoomImagePack(StrippedStateEvent<PossiblyRedactedRoomImagePackEventContent>)
m.room.image_pack
RoomJoinRules(StrippedStateEvent<RoomJoinRulesEventContent>)
m.room.join_rules
RoomLanguage(StrippedStateEvent<PossiblyRedactedRoomLanguageEventContent>)
unstable-msc4334 only.m.room.language
This variant uses the unstable type org.matrix.msc4334.room.language.
This variant can also be deserialized from the m.room.language type.
RoomMember(StrippedStateEvent<PossiblyRedactedRoomMemberEventContent>)
m.room.member
RoomName(StrippedStateEvent<PossiblyRedactedRoomNameEventContent>)
m.room.name
RoomPinnedEvents(StrippedStateEvent<PossiblyRedactedRoomPinnedEventsEventContent>)
m.room.pinned_events
RoomPolicy(StrippedStateEvent<PossiblyRedactedRoomPolicyEventContent>)
m.room.policy
RoomPowerLevels(StrippedStateEvent<RoomPowerLevelsEventContent>)
m.room.power_levels
RoomRetention(StrippedStateEvent<RoomRetentionEventContent>)
unstable-msc1763 only.m.room.retention
This variant uses the unstable type org.matrix.msc1763.retention.
This variant can also be deserialized from the m.room.retention type.
RoomServerAcl(StrippedStateEvent<RoomServerAclEventContent>)
m.room.server_acl
RoomThirdPartyInvite(StrippedStateEvent<RoomThirdPartyInviteEventContent>)
m.room.third_party_invite
RoomTombstone(StrippedStateEvent<PossiblyRedactedRoomTombstoneEventContent>)
m.room.tombstone
RoomTopic(StrippedStateEvent<PossiblyRedactedRoomTopicEventContent>)
m.room.topic
RoomPresenceSharing(StrippedStateEvent<PossiblyRedactedRoomPresenceSharingEventContent>)
unstable-msc4495 only.m.room.presence_sharing
This variant uses the unstable type org.continuwuity.presence_v2.msc4495.room.presence_sharing.
This variant can also be deserialized from the m.room.presence_sharing type.
SpaceChild(StrippedStateEvent<PossiblyRedactedSpaceChildEventContent>)
m.space.child
SpaceParent(StrippedStateEvent<PossiblyRedactedSpaceParentEventContent>)
m.space.parent
BeaconInfo(StrippedStateEvent<PossiblyRedactedBeaconInfoEventContent>)
unstable-msc3489 only.m.beacon_info
This variant uses the unstable type org.matrix.msc3672.beacon_info.
This variant can also be deserialized from the m.beacon_info type.
CallMember(StrippedStateEvent<CallMemberEventContent>)
unstable-msc3401 only.m.call.member
This variant uses the unstable type org.matrix.msc3401.call.member.
This variant can also be deserialized from the m.call.member type.
MemberHints(StrippedStateEvent<PossiblyRedactedMemberHintsEventContent>)
unstable-msc4171 only.m.member_hints
This variant uses the unstable type io.element.functional_members.
This variant can also be deserialized from the m.member_hints type.
Implementations
Sourceimpl AnyStrippedStateEvent
impl AnyStrippedStateEvent
Sourcepub fn event_type(&self) -> StateEventType
pub fn event_type(&self) -> StateEventType
Returns the type of this event.
Sourcepub fn content(&self) -> AnyPossiblyRedactedStateEventContent
pub fn content(&self) -> AnyPossiblyRedactedStateEventContent
Returns the content for this event.