#[non_exhaustive]pub enum AnyToDeviceEvent {
Show 21 variants
Dummy(ToDeviceEvent<ToDeviceDummyEventContent>),
RoomKey(ToDeviceEvent<ToDeviceRoomKeyEventContent>),
RoomKeyBundle(ToDeviceEvent<ToDeviceRoomKeyBundleEventContent>),
RoomKeyRequest(ToDeviceEvent<ToDeviceRoomKeyRequestEventContent>),
RoomKeyWithheld(ToDeviceEvent<ToDeviceRoomKeyWithheldEventContent>),
ForwardedRoomKey(ToDeviceEvent<ToDeviceForwardedRoomKeyEventContent>),
KeyVerificationRequest(ToDeviceEvent<ToDeviceKeyVerificationRequestEventContent>),
KeyVerificationReady(ToDeviceEvent<ToDeviceKeyVerificationReadyEventContent>),
KeyVerificationStart(ToDeviceEvent<ToDeviceKeyVerificationStartEventContent>),
KeyVerificationCancel(ToDeviceEvent<ToDeviceKeyVerificationCancelEventContent>),
KeyVerificationAccept(ToDeviceEvent<ToDeviceKeyVerificationAcceptEventContent>),
KeyVerificationKey(ToDeviceEvent<ToDeviceKeyVerificationKeyEventContent>),
KeyVerificationMac(ToDeviceEvent<ToDeviceKeyVerificationMacEventContent>),
KeyVerificationDone(ToDeviceEvent<ToDeviceKeyVerificationDoneEventContent>),
RoomEncrypted(ToDeviceEvent<ToDeviceRoomEncryptedEventContent>),
SecretRequest(ToDeviceEvent<ToDeviceSecretRequestEventContent>),
SecretSend(ToDeviceEvent<ToDeviceSecretSendEventContent>),
SecretPush(ToDeviceEvent<ToDeviceSecretPushEventContent>),
StreamSubscribe(ToDeviceEvent<ToDeviceStreamSubscribeEventContent>),
StreamCancel(ToDeviceEvent<ToDeviceStreamCancelEventContent>),
StreamUpdate(ToDeviceEvent<ToDeviceStreamUpdateEventContent>),
}events only.Expand description
Any to-device event.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Dummy(ToDeviceEvent<ToDeviceDummyEventContent>)
m.dummy
RoomKey(ToDeviceEvent<ToDeviceRoomKeyEventContent>)
m.room_key
RoomKeyBundle(ToDeviceEvent<ToDeviceRoomKeyBundleEventContent>)
m.room_key_bundle
RoomKeyRequest(ToDeviceEvent<ToDeviceRoomKeyRequestEventContent>)
m.room_key_request
RoomKeyWithheld(ToDeviceEvent<ToDeviceRoomKeyWithheldEventContent>)
m.room_key.withheld
ForwardedRoomKey(ToDeviceEvent<ToDeviceForwardedRoomKeyEventContent>)
m.forwarded_room_key
KeyVerificationRequest(ToDeviceEvent<ToDeviceKeyVerificationRequestEventContent>)
m.key.verification.request
KeyVerificationReady(ToDeviceEvent<ToDeviceKeyVerificationReadyEventContent>)
m.key.verification.ready
KeyVerificationStart(ToDeviceEvent<ToDeviceKeyVerificationStartEventContent>)
m.key.verification.start
KeyVerificationCancel(ToDeviceEvent<ToDeviceKeyVerificationCancelEventContent>)
m.key.verification.cancel
KeyVerificationAccept(ToDeviceEvent<ToDeviceKeyVerificationAcceptEventContent>)
m.key.verification.accept
KeyVerificationKey(ToDeviceEvent<ToDeviceKeyVerificationKeyEventContent>)
m.key.verification.key
KeyVerificationMac(ToDeviceEvent<ToDeviceKeyVerificationMacEventContent>)
m.key.verification.mac
KeyVerificationDone(ToDeviceEvent<ToDeviceKeyVerificationDoneEventContent>)
m.key.verification.done
RoomEncrypted(ToDeviceEvent<ToDeviceRoomEncryptedEventContent>)
m.room.encrypted
SecretRequest(ToDeviceEvent<ToDeviceSecretRequestEventContent>)
m.secret.request
SecretSend(ToDeviceEvent<ToDeviceSecretSendEventContent>)
m.secret.send
SecretPush(ToDeviceEvent<ToDeviceSecretPushEventContent>)
unstable-msc4385 only.m.secret.push
This variant uses the unstable type io.element.msc4385.secret.push.
This variant can also be deserialized from the m.secret.push type.
StreamSubscribe(ToDeviceEvent<ToDeviceStreamSubscribeEventContent>)
unstable-msc4471 only.m.stream.subscribe
This variant uses the unstable type org.matrix.msc4471.stream.subscribe.
This variant can also be deserialized from the m.stream.subscribe type.
StreamCancel(ToDeviceEvent<ToDeviceStreamCancelEventContent>)
unstable-msc4471 only.m.stream.cancel
This variant uses the unstable type org.matrix.msc4471.stream.cancel.
This variant can also be deserialized from the m.stream.cancel type.
StreamUpdate(ToDeviceEvent<ToDeviceStreamUpdateEventContent>)
unstable-msc4471 only.m.stream.update
This variant uses the unstable type org.matrix.msc4471.stream.update.
This variant can also be deserialized from the m.stream.update type.
Implementations
Sourceimpl AnyToDeviceEvent
impl AnyToDeviceEvent
Sourcepub fn event_type(&self) -> ToDeviceEventType
pub fn event_type(&self) -> ToDeviceEventType
Returns the type of this event.
Sourcepub fn content(&self) -> AnyToDeviceEventContent
pub fn content(&self) -> AnyToDeviceEventContent
Returns the content for this event.