pub enum StateEvent<C>where
C: StaticStateEventContent + RedactContent,
<C as RedactContent>::Redacted: RedactedStateEventContent,{
Original(OriginalStateEvent<C>),
Redacted(RedactedStateEvent<<C as RedactContent>::Redacted>),
}events only.Expand description
A possibly-redacted state event.
StateEvent implements the comparison traits using only the event_id field, a sorted list
would be sorted lexicographically based on the event’s EventId.
Variants
Original(OriginalStateEvent<C>)
Original, unredacted form of the event.
Redacted(RedactedStateEvent<<C as RedactContent>::Redacted>)
Redacted form of the event with minimal fields.
Implementations
Sourceimpl<C> StateEvent<C>where
C: StaticStateEventContent + RedactContent,
<C as RedactContent>::Redacted: RedactedStateEventContent<StateKey = <C as StateEventContent>::StateKey> + RedactedStateEventContent,
impl<C> StateEvent<C>where
C: StaticStateEventContent + RedactContent,
<C as RedactContent>::Redacted: RedactedStateEventContent<StateKey = <C as StateEventContent>::StateKey> + RedactedStateEventContent,
Sourcepub fn event_type(&self) -> StateEventType
Available on crate feature unstable-msc3489 only.
pub fn event_type(&self) -> StateEventType
unstable-msc3489 only.Returns the type of this event.
Sourcepub fn event_id(&self) -> &EventId
Available on crate feature unstable-msc3489 only.
pub fn event_id(&self) -> &EventId
unstable-msc3489 only.Returns this event’s event_id field.
Sourcepub fn sender(&self) -> &UserId
Available on crate feature unstable-msc3489 only.
pub fn sender(&self) -> &UserId
unstable-msc3489 only.Returns this event’s sender field.
Sourcepub fn origin_server_ts(&self) -> MilliSecondsSinceUnixEpoch
Available on crate feature unstable-msc3489 only.
pub fn origin_server_ts(&self) -> MilliSecondsSinceUnixEpoch
unstable-msc3489 only.Returns this event’s origin_server_ts field.
Sourcepub fn room_id(&self) -> &RoomId
Available on crate feature unstable-msc3489 only.
pub fn room_id(&self) -> &RoomId
unstable-msc3489 only.Returns this event’s room_id field.
Sourcepub fn state_key(&self) -> &<C as StateEventContent>::StateKey
Available on crate feature unstable-msc3489 only.
pub fn state_key(&self) -> &<C as StateEventContent>::StateKey
unstable-msc3489 only.Returns this event’s state_key field.
Sourcepub fn as_original(&self) -> Option<&OriginalStateEvent<C>>
Available on crate feature unstable-msc3489 only.
pub fn as_original(&self) -> Option<&OriginalStateEvent<C>>
unstable-msc3489 only.Get the inner OriginalStateEvent if this is an unredacted event.
Sourceimpl StateEvent<RoomGuestAccessEventContent>
impl StateEvent<RoomGuestAccessEventContent>
Sourcepub fn guest_access(&self) -> &GuestAccess
Available on crate feature unstable-msc3489 only.
pub fn guest_access(&self) -> &GuestAccess
unstable-msc3489 only.Obtain the guest access policy, regardless of whether this event is redacted.
Sourceimpl StateEvent<RoomHistoryVisibilityEventContent>
impl StateEvent<RoomHistoryVisibilityEventContent>
Sourcepub fn history_visibility(&self) -> &HistoryVisibility
Available on crate feature unstable-msc3489 only.
pub fn history_visibility(&self) -> &HistoryVisibility
unstable-msc3489 only.Obtain the history visibility, regardless of whether this event is redacted.
Sourceimpl StateEvent<RoomMemberEventContent>
impl StateEvent<RoomMemberEventContent>
Sourcepub fn membership(&self) -> &MembershipState
Available on crate feature unstable-msc3489 only.
pub fn membership(&self) -> &MembershipState
unstable-msc3489 only.Obtain the membership state, regardless of whether this event is redacted.
Sourcepub fn should_redact_events(&self) -> bool
Available on crate features unstable-msc3489 and unstable-msc4293 only.
pub fn should_redact_events(&self) -> bool
unstable-msc3489 and unstable-msc4293 only.Determines whether the user’s events should be redacted based on their membership.
Using MSC4293, if redact_events is true, the sender is different to the state key,
and the membership is ban or leave (kick), true is returned. Otherwise, the flag
should be ignored, and false is returned.
Sourceimpl StateEvent<RoomPowerLevelsEventContent>
impl StateEvent<RoomPowerLevelsEventContent>
Sourcepub fn power_levels(
&self,
rules: &AuthorizationRules,
creators: Vec<OwnedUserId>,
) -> RoomPowerLevels
Available on crate feature unstable-msc3489 only.
pub fn power_levels( &self, rules: &AuthorizationRules, creators: Vec<OwnedUserId>, ) -> RoomPowerLevels
unstable-msc3489 only.Obtain the effective power levels, regardless of whether this event is redacted.