SyncStateEvent

Enum SyncStateEvent 

pub enum SyncStateEvent<C>{
    Original(OriginalSyncStateEvent<C>),
    Redacted(RedactedSyncStateEvent<<C as RedactContent>::Redacted>),
}
Available on crate feature events only.
A possibly-redacted state event without a room_id.

SyncStateEvent implements the comparison traits using only the event_id field, a sorted list would be sorted lexicographically based on the event’s EventId.

Variants



Original(OriginalSyncStateEvent<C>)

Original, unredacted form of the event.



Redacted(RedactedSyncStateEvent<<C as RedactContent>::Redacted>)

Redacted form of the event with minimal fields.

Implementations

Source

impl<C> SyncStateEvent<C>

pub fn event_type(&self) -> StateEventType

Available on crate feature unstable-msc3489 only.

Returns the type of this event.

pub fn event_id(&self) -> &EventId

Available on crate feature unstable-msc3489 only.

Returns this event’s event_id field.

pub fn sender(&self) -> &UserId

Available on crate feature unstable-msc3489 only.

Returns this event’s sender field.

pub fn origin_server_ts(&self) -> MilliSecondsSinceUnixEpoch

Available on crate feature unstable-msc3489 only.

Returns this event’s origin_server_ts field.

pub fn state_key(&self) -> &<C as StateEventContent>::StateKey

Available on crate feature unstable-msc3489 only.

Returns this event’s state_key field.

pub fn as_original(&self) -> Option<&OriginalSyncStateEvent<C>>

Available on crate feature unstable-msc3489 only.

Get the inner OriginalSyncStateEvent if this is an unredacted event.

pub fn into_full_event(self, room_id: OwnedRoomId) -> StateEvent<C>

Available on crate feature unstable-msc3489 only.

Convert this sync event into a full event (one with a room_id field).

Source

impl SyncStateEvent<RoomGuestAccessEventContent>

pub fn guest_access(&self) -> &GuestAccess

Available on crate feature unstable-msc3489 only.

Obtain the guest access policy, regardless of whether this event is redacted.

Source

impl SyncStateEvent<RoomHistoryVisibilityEventContent>

pub fn history_visibility(&self) -> &HistoryVisibility

Available on crate feature unstable-msc3489 only.

Obtain the history visibility, regardless of whether this event is redacted.

Source

impl SyncStateEvent<RoomJoinRulesEventContent>

pub fn join_rule(&self) -> &JoinRule

Available on crate feature unstable-msc3489 only.

Obtain the join rule, regardless of whether this event is redacted.

Source

impl SyncStateEvent<RoomMemberEventContent>

pub fn membership(&self) -> &MembershipState

Available on crate feature unstable-msc3489 only.

Obtain the membership state, regardless of whether this event is redacted.

pub fn should_redact_events(&self) -> bool

Available on crate features unstable-msc3489 and unstable-msc4293 only.

Determines whether the user’s events should be redacted based on their membership.

Using MSC4293, if redact_events is true, the sender is different to the state key, and the membership is ban or leave (kick), true is returned. Otherwise, the flag should be ignored, and false is returned.

Source

impl SyncStateEvent<RoomPowerLevelsEventContent>

pub fn power_levels( &self, rules: &AuthorizationRules, creators: Vec<OwnedUserId>, ) -> RoomPowerLevels

Available on crate feature unstable-msc3489 only.

Obtain the effective power levels, regardless of whether this event is redacted.