#[non_exhaustive]pub struct OriginalStateEvent<C>where
C: StaticStateEventContent,{
pub content: C,
pub event_id: OwnedEventId,
pub sender: OwnedUserId,
pub origin_server_ts: MilliSecondsSinceUnixEpoch,
pub room_id: OwnedRoomId,
pub state_key: <C as StateEventContent>::StateKey,
pub unsigned: <C as StaticStateEventContent>::Unsigned,
}events only.Expand description
An unredacted state event.
OriginalStateEvent implements the comparison traits using only the event_id field, a sorted
list would be sorted lexicographically based on the event’s EventId.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.content: CData specific to the event type.
event_id: OwnedEventIdThe globally unique identifier for the event.
sender: OwnedUserIdThe fully-qualified ID of the user who sent this event.
origin_server_ts: MilliSecondsSinceUnixEpochTimestamp on the originating homeserver when this event was sent.
room_id: OwnedRoomIdThe ID of the room associated with this event.
state_key: <C as StateEventContent>::StateKeyA unique key which defines the overwriting semantics for this piece of room state.
This must be a string type, and is often an empty string.
A state event is keyed by its (type, state_key) tuple. Sending another state event with
the same tuple replaces the previous one.
unsigned: <C as StaticStateEventContent>::UnsignedAdditional key-value pairs not signed by the homeserver.
Implementations
Sourceimpl<C> OriginalStateEvent<C>where
C: StaticStateEventContent,
impl<C> OriginalStateEvent<C>where
C: StaticStateEventContent,
Sourcepub fn event_type(&self) -> StateEventType
Available on crate feature unstable-msc3489 only.
pub fn event_type(&self) -> StateEventType
unstable-msc3489 only.Get the event’s type.
Sourceimpl OriginalStateEvent<RoomMemberEventContent>
impl OriginalStateEvent<RoomMemberEventContent>
Sourcepub fn details(&self) -> MembershipDetails<'_>
Available on crate feature unstable-msc3489 only.
pub fn details(&self) -> MembershipDetails<'_>
unstable-msc3489 only.Obtain the details about this event that are required to calculate a membership change.
This is required when you want to calculate the change a redacted m.room.member event
made.
Sourcepub fn prev_content(&self) -> Option<&PossiblyRedactedRoomMemberEventContent>
Available on crate feature unstable-msc3489 only.
pub fn prev_content(&self) -> Option<&PossiblyRedactedRoomMemberEventContent>
unstable-msc3489 only.Get a reference to the prev_content in unsigned, if it exists.
Shorthand for event.unsigned.prev_content.as_ref()
Sourcepub fn membership_change(&self) -> MembershipChange<'_>
Available on crate feature unstable-msc3489 only.
pub fn membership_change(&self) -> MembershipChange<'_>
unstable-msc3489 only.Helper function for membership change.
Check the specification for details.
Sourcepub fn should_redact_events(&self) -> bool
Available on crate features unstable-msc3489 and unstable-msc4293 only.
pub fn should_redact_events(&self) -> bool
unstable-msc3489 and unstable-msc4293 only.Determines whether the user’s events should be redacted based on their membership.
Using MSC4293, if redact_events is true, the sender is different to the state key,
and the membership is ban or leave (kick), true is returned. Otherwise, the flag
should be ignored, and false is returned.