StrippedStateEvent

Struct StrippedStateEvent 

#[non_exhaustive]
pub struct StrippedStateEvent<C>{ pub content: C, pub sender: OwnedUserId, pub state_key: <C as PossiblyRedactedStateEventContent>::StateKey, pub origin_server_ts: Option<MilliSecondsSinceUnixEpoch>, pub unsigned: Option<Raw<StateUnsigned<C>>>, }
Available on crate feature events only.
A stripped-down state event, used for previews of rooms the user has been invited to.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
content: C

Data specific to the event type.

sender: OwnedUserId

The fully-qualified ID of the user who sent this event.

state_key: <C as PossiblyRedactedStateEventContent>::StateKey

A unique key which defines the overwriting semantics for this piece of room state.

This must be a string type, and is often an empty string.

A state event is keyed by its (type, state_key) tuple. Sending another state event with the same tuple replaces the previous one.

origin_server_ts: Option<MilliSecondsSinceUnixEpoch>
Available on crate feature unstable-msc4319 only.

Timestamp on the originating homeserver when this event was sent.

This field is usually stripped, but some events might include it.

unsigned: Option<Raw<StateUnsigned<C>>>
Available on crate feature unstable-msc4319 only.

Additional key-value pairs not signed by the homeserver.

Implementations

Source

impl<C> StrippedStateEvent<C>

pub fn event_type(&self) -> StateEventType

Available on crate feature unstable-msc3489 only.

Get the event’s type.

Source

impl StrippedStateEvent<PossiblyRedactedRoomMemberEventContent>

pub fn details(&self) -> MembershipDetails<'_>

Available on crate feature unstable-msc3489 only.

Obtain the details about this event that are required to calculate a membership change.

This is required when you want to calculate the change a redacted m.room.member event made.

pub fn membership_change<'a>( &'a self, prev_details: Option<MembershipDetails<'a>>, ) -> MembershipChange<'a>

Available on crate feature unstable-msc3489 only.

Helper function for membership change.

Since stripped events don’t have unsigned.prev_content, you have to pass the .details() of the previous m.room.member event manually (if there is a previous m.room.member event).

Check the specification for details.

pub fn should_redact_events(&self) -> bool

Available on crate features unstable-msc3489 and unstable-msc4293 only.

Determines whether the user’s events should be redacted based on their membership.

Using MSC4293, if redact_events is true, the sender is different to the state key, and the membership is ban or leave (kick), true is returned. Otherwise, the flag should be ignored, and false is returned.

Source

impl StrippedStateEvent<RoomPowerLevelsEventContent>

pub fn power_levels( &self, rules: &AuthorizationRules, creators: Vec<OwnedUserId>, ) -> RoomPowerLevels

Available on crate feature unstable-msc3489 only.

Obtain the effective power levels from this event.