#[non_exhaustive]pub struct RedactedSyncStateEvent<C>where
C: RedactedStateEventContent,{
pub content: C,
pub event_id: OwnedEventId,
pub sender: OwnedUserId,
pub origin_server_ts: MilliSecondsSinceUnixEpoch,
pub state_key: <C as RedactedStateEventContent>::StateKey,
pub unsigned: RedactedUnsigned,
}events only.Expand description
A redacted state event without a room_id.
RedactedSyncStateEvent implements the comparison traits using only the event_id field, a
sorted list would be sorted lexicographically based on the event’s EventId.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.content: CData specific to the event type.
event_id: OwnedEventIdThe globally unique identifier for the event.
sender: OwnedUserIdThe fully-qualified ID of the user who sent this event.
origin_server_ts: MilliSecondsSinceUnixEpochTimestamp on the originating homeserver when this event was sent.
state_key: <C as RedactedStateEventContent>::StateKeyA unique key which defines the overwriting semantics for this piece of room state.
This must be a string type, and is often an empty string.
A state event is keyed by its (type, state_key) tuple. Sending another state event with
the same tuple replaces the previous one.
unsigned: RedactedUnsignedAdditional key-value pairs not signed by the homeserver.
Implementations
Sourceimpl<C> RedactedSyncStateEvent<C>where
C: RedactedStateEventContent,
impl<C> RedactedSyncStateEvent<C>where
C: RedactedStateEventContent,
Sourcepub fn event_type(&self) -> StateEventType
Available on crate feature unstable-msc3489 only.
pub fn event_type(&self) -> StateEventType
unstable-msc3489 only.Get the event’s type.
Sourceimpl<C> RedactedSyncStateEvent<C>where
C: RedactedStateEventContent,
impl<C> RedactedSyncStateEvent<C>where
C: RedactedStateEventContent,
Sourcepub fn into_full_event(self, room_id: OwnedRoomId) -> RedactedStateEvent<C>
Available on crate feature unstable-msc3489 only.
pub fn into_full_event(self, room_id: OwnedRoomId) -> RedactedStateEvent<C>
unstable-msc3489 only.Convert this sync event into a full event, one with a room_id field.
Sourceimpl RedactedSyncStateEvent<RedactedRoomMemberEventContent>
impl RedactedSyncStateEvent<RedactedRoomMemberEventContent>
Sourcepub fn details(&self) -> MembershipDetails<'_>
Available on crate feature unstable-msc3489 only.
pub fn details(&self) -> MembershipDetails<'_>
unstable-msc3489 only.Obtain the details about this event that are required to calculate a membership change.
This is required when you want to calculate the change a redacted m.room.member event
made.
Sourcepub fn membership_change<'a>(
&'a self,
prev_details: Option<MembershipDetails<'a>>,
) -> MembershipChange<'a>
Available on crate feature unstable-msc3489 only.
pub fn membership_change<'a>( &'a self, prev_details: Option<MembershipDetails<'a>>, ) -> MembershipChange<'a>
unstable-msc3489 only.Helper function for membership change.
Since redacted events don’t have unsigned.prev_content, you have to pass the .details()
of the previous m.room.member event manually (if there is a previous m.room.member
event).
Check the specification for details.
Sourcepub fn should_redact_events(&self) -> bool
Available on crate features unstable-msc3489 and unstable-msc4293 only.
pub fn should_redact_events(&self) -> bool
unstable-msc3489 and unstable-msc4293 only.Determines whether the user’s events should be redacted based on their membership.
Using MSC4293, if redact_events is true, the sender is different to the state key,
and the membership is ban or leave (kick), true is returned. Otherwise, the flag
should be ignored, and false is returned.